@@ -1,25 +1,37 @@
 =head1 NAME
 
-Clustericious::Command::apache
+Clustericious::Command::apache - Clustericious command to stat Apache
+
+=head1 SYNOPSIS
+
+ % yourapp start
 
 =head1 DESCRIPTION
 
 Start an apache web server.
 
+=head1 SUPER CLASS
+
+L<Clustericious::Command>
+
+=head1 SEE ALSO
+
+L<Clustericious>
+
 =cut
 
 package Clustericious::Command::apache;
 use Clustericious::App;
 use Clustericious::Config;
 use File::Path qw/mkpath/;
-use base 'Mojolicious::Command';
+use base 'Clustericious::Command';
 
 use Clustericious::Log;
 __PACKAGE__->attr(description => <<EOT);
 Start an apache web server.
 EOT
 
-our $VERSION = '0.9921';
+our $VERSION = '0.9922';
 
 __PACKAGE__->attr(usage => <<EOT);
 Usage $0: apache -f <conf> [...other apache options]
