@@ -10,7 +10,29 @@ use File::Slurp 'slurp';
 use File::ShareDir 'dist_dir';
 use File::Basename qw/basename/;
 
-our $VERSION = '0.9921';
+=head1 NAME
+
+Clustericious::Command::generate::client - Clustericious command to generate a new Clustericious client
+
+=head1 SYNOPSIS
+
+ % clustericious generate client Myapp
+
+=head1 DESCRIPTION
+
+This command generates a new Clustericious client with the given name.
+
+=head1 SUPER CLASS
+
+L<Clustericious::Command>
+
+=head1 SEE ALSO
+
+L<Clustericious>, L<Clustericious::Client>
+
+=cut
+
+our $VERSION = '0.9922';
 
 has description => <<'EOF';
 Generate Clustericious::Client-derived client.
