@@ -7,7 +7,33 @@ use base 'Mojolicious::Controller';
 use strict;
 use warnings;
 
-our $VERSION = '0.9921';
+=head1 NAME
+
+Clustericious::Controller - Clustericious controller base class
+
+=head1 SYNOPSIS
+
+ use base qw( Clustericious::Controller );
+
+=head1 DESCRIPTION
+
+Base class for all controllers in Clustericious applications
+
+=head1 SUPER CLASS
+
+L<Mojolicious::Controller>
+
+=cut
+
+our $VERSION = '0.9922';
+
+=head1 METHODS
+
+=head2 $c-E<gt>url_for
+
+Clustericious version of this method usually provided by Mojolicious.
+
+=cut
 
 sub url_for {
     my $c = shift;
@@ -23,7 +49,7 @@ sub url_for {
     return $url;
 }
 
-=head1 redirect_to
+=head2 redirect_to
 
 Copied from Mojolicious::Controller, but works around
 a limitation of apache's mod_proxy (namely: the ProxyPassReverse
@@ -62,12 +88,32 @@ sub redirect_to {
     return $self;
 }
 
+=head2 $c-E<gt>render_not_found
+
+Clustericious version of this method usually provided by Mojolicious.
+
+=cut
+
 sub render_not_found {
     my $self = shift;
     undef $self->stash->{autodata} if exists($self->stash->{autodata});
     $self->SUPER::render_not_found(@_);
 }
 
+=head2 $c-E<gt>render_text
+
+Only provided when Mojolicious < 4.0.  Previous versions of Mojolicious included this
+method, and it was added here to ease the transition.  This method should be considered
+deprecated and may be removed in the future.
+
+=head2 $c-E<gt>render_json
+
+Only provided when Mojolicious < 4.0.  Previous versions of Mojolicious included this
+method, and it was added here to ease the transition.  This method should be considered
+deprecated and may be removed in the future.
+
+=cut
+
 if($Mojolicious::VERSION >= 4.0)
 {
     foreach my $type (qw( text json )) {
@@ -80,3 +126,8 @@ if($Mojolicious::VERSION >= 4.0)
 
 1;
 
+=head1 SEE ALSO
+
+L<Clustericious>
+
+=cut
\ No newline at end of file
