@@ -1,14 +1,16 @@
 =head1 NAME
 
-Clustericious::Renderer -- renderer for clustericious
+Clustericious::Renderer - renderer for clustericious
 
 =head1 DESCRIPTION
 
 Just inherits from Mojolicious::Renderer with some customizations.
 
-=head1 METHODS
+=head1 SUPER CLASS
 
-=over
+L<Mojolicious::Renderer>
+
+=head1 METHODS
 
 =cut
 
@@ -19,9 +21,9 @@ use base 'Mojolicious::Renderer';
 use strict;
 use warnings;
 
-our $VERSION = '0.9921';
+our $VERSION = '0.9922';
 
-=item render
+=head2 render
 
 Set the hander to "autodata" if there is some autodata
 present in the stash.
@@ -46,3 +48,8 @@ sub root  {
 
 1;
 
+=head1 SEE ALSO
+
+L<Clustericious>
+
+=cut
