@@ -1,6 +1,6 @@
 =head1 NAME
 
-Clustericious::RouteBuilder::Common -- Routes common to all clustericious apps.
+Clustericious::RouteBuilder::Common - Routes common to all clustericious apps.
 
 =head1 SYNOPSIS
 
@@ -22,13 +22,21 @@ routes are added :
 /log is not available unless the configuration option "export_logs" is set
 to a true value.
 
+=head1 SUPER CLASS
+
+none
+
+=head1 SEE ALSO
+
+L<Clustericious>
+
 =cut
 
 package Clustericious::RouteBuilder::Common;
 use Clustericious::Log;
 use Sys::Hostname qw/hostname/;
 
-our $VERSION = '0.9921';
+our $VERSION = '0.9922';
 
 use strict;
 use warnings;
