@@ -1,18 +1,21 @@
-
 =head1 NAME
 
-Clustericious::Templates -- default templates for clustericious
+Clustericious::Templates - default templates for clustericious
 
 =head1 DESCRIPTION
 
 This package contains some default templates (inline) for clustericious.
 Anything on the filesystem (in templates/) will override these.
 
+=head1 SEE ALSO
+
+L<Clustericious>
+
 =cut
 
 package Clustericious::Templates;
 
-our $VERSION = '0.9921';
+our $VERSION = '0.9922';
 
 1;
 
